@@ -1,7 +1,7 @@
 package Mojo::Util::Collection;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -118,18 +118,6 @@ sub each {
     $callback->($_) for (@{ $self->objects });
 }
 
-=head2 eq
-
-Get object by index
-
-=cut
-
-sub eq {
-    my ($self, $index) = @_;
-
-    return $self->objects->[$index];
-}
-
 =head2 exclude
 
 Exclude objects that doesn't match criteria
@@ -224,7 +212,7 @@ C<Model> object
 =cut
 
 sub first {
-    return shift->eq(0);
+    return shift->get(0);
 }
 
 =head2 firstOrNew
@@ -237,16 +225,14 @@ C<Model> object
 =cut
 
 sub firstOrNew {
-    my ($self, $args, $extra) = @_;
+    my ($self, $args) = @_;
 
-    my %new_args = (%{ $args || {} }, %{ $extra || {} });
-
-    return $self->eq(0) || $self->new_object(%new_args);
+    return $self->first || $self->new_object(%$args);
 }
 
 =head2 get
 
-Get a collection with elements starting at $start and ending at $end
+Get object by index
 
 Returns:
 C<Collection> of C<Model> objects
@@ -254,20 +240,9 @@ C<Collection> of C<Model> objects
 =cut
 
 sub get {
-    my ($self, $start, $stop) = @_;
+    my ($self, $index) = @_;
 
-    if (! $stop) {
-        $stop = $start - 1;
-        $start = 0;
-    }
-
-    if ($stop > scalar(@{ $self->objects })) {
-        $stop = scalar(@{ $self->objects }) - 1;
-    }
-
-    my @objects = @{ $self->objects }[$start .. $stop];
-
-    return $self->new({ objects => \@objects, model => $self->model });
+    return $self->objects->[$index];
 }
 
 =head2 indexOf
@@ -308,7 +283,7 @@ C<Model> object
 sub last {
     my $self= shift;
 
-    return $self->eq(scalar(@{ $self->objects }) - 1);
+    return $self->get(scalar(@{ $self->objects }) - 1);
 }
 
 =head2 lists
@@ -344,7 +319,7 @@ C<Model> object
 sub new_object {
     my $self = shift;
 
-    return $self->model->new(@_, app => $self->model->app);
+    return $self->model->new(@_);
 }
 
 =head2 next
@@ -362,7 +337,7 @@ sub next {
 
     $self->index($index + 1);
 
-    my $object = $self->eq($index);
+    my $object = $self->get($index);
 
     # Auto reset
     if (! $object) {
