@@ -1,7 +1,7 @@
 package Mojo::Util::Collection::Comparator;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 
 use List::Util qw(all any none);
 
@@ -34,7 +34,7 @@ sub between {
 
     my ($min, $max) = @$values;
 
-    return $self->_greater_than($search, $min) && $self->_less_than($search, $max) ? 1 : 0;
+    return $self->gt($search, $min) && $self->lt($search, $max) ? 1 : 0;
 }
 
 =head2 eq
